==> patch-2.5.4.3_2.zip: app/templates/default/footer.php <==
<!-- FOR EVERY PAGE THE BELOW CODE SHOULD BE ADDED -->
<script>
    NProgress.start();
    var interval = setInterval(function() { NProgress.inc(); }, 1000);
    //$(window).load(function () {
    $(window).on('load',function () {
        clearInterval(interval);
        NProgress.done();
    });
    //$(window).unload(function () {
    $(window).on('unload',function () {
        NProgress.start();
    });
    if($('.selectPicker')){
        $('.selectPicker').selectpicker();
    }
</script>
<script>
$('.my-dropdown').dropdown();
$('.my-dropdown').tooltip();
</script>
<?php if(ENABLE_IDEAL_TIMEOUT == true){?>
<script>
$(document).mousemove(function() {
ResetTimers();
});
// Logout the user.
function IdleTimeout() {
var env = $('.paracloudIP').html();
env = $('.protocol').html()+env+"/portal/logout";
var logoutUrl = env;
    window.location = logoutUrl;
}
    /*end*/
</script>
<?php } ?>

<script>         
    $('.searchUsernameOutlookSearchFileGS').select2({
        ajax: {
            url: "<?=DIR?>"+"user/searchUserWithDevice",
            dataType: 'json',
            delay: 250,
            data: function (params) {
                return {
                    q: params.term, // search term
                    page: params.page
                };
            },
            processResults: function (data, params) {
                params.page = params.page || 1;
                if(data.users.length > 0){
                    $('.assignSaveBtn').removeAttr('disabled');
                }
                return {
                    results: $.map(data.users, function (o) {
                        return { id: o.userName, text: o.userName, img: o.profilePic, devices: o.devices };
                    }),
                    pagination: {
                        more: (params.page * 30) < data.total_count
                    }
                };
            },
            cache: true
        },
        escapeMarkup: function (markup) { return markup; }, // let our custom formatter work
        minimumInputLength: 3,
        dropdownParent: $('.restoreBuckettOutlookSearchFileGS'),
        templateResult: selectTemplateResultOutlookSearchFileGS,
        templateSelection: selectTemplateSelectionOutlookSearchFileGS,
        placeholder: 'Select user'
    });

    function selectTemplateResultOutlookSearchFileGS(users){
        if(users.text != undefined){
            var template = "<div class='select2-result-repository clearfix'><div class='select2-result-repository__avatar'>";
            if(users.img){
                template += "<img style='-webkit-border-radius: 50px;-moz-border-radius: 50px;border-radius: 50px;' width='30px' height='30px' src='"+ users.img +"'> ";
            }
            template += users.text + "</div></div>";
            return template;
        }else{
            return "<div class='select2-user-result'>Fetching...</div>";
        }
    }

    function selectTemplateSelectionOutlookSearchFileGS(users){
            console.log("gggggggg : "+users.text);
            if(users.text != 'Select user'){
            $.ajax({
            url: "<?=DIR?>"+"getDeviceOutlook",
            data: {username: users.text, csrf_token: $('.csrf_token').html()},
            type: 'POST'
            }).done(function(data){
                console.log(data);
                var jData = JSON.parse(data);
                console.log("newone111 : "+jData.newone1);
                if (jData.newone1){
                var options = "";
                jData.newone1.forEach(function (device) {
                        options += '<option value="' + device.deviceUUID + '">' + device.deviceName + '</option>'
                });
                $('.searchDeviceNameOutlookSearchFileGS').html(options);
                /*xx start*/
                $("#uuuOutlookSearchFileGS").val(jData.newone1[0].deviceUUID);
                /*xx end*/
                    }else{
                    $('.searchDeviceNameOutlookSearchFileGS').html("<option value='all' selected>User has no devices configured</option>");
                    $('.searchDeviceNameOutlookSearchFileGS').attr("readonly", "readonly");
                    $("#uuuOutlookSearchFileGS").val('');
                }
            }).fail(function(data){
                if(data.status == 424){
                    setTimeout(function(){
                        window.location.href = $scope.BASE_FOLDER+'/sleep';
                    }, 3000);
                }else if(data.status == 503){
                    setTimeout(function(){
                        window.location.href = $scope.BASE_FOLDER+'/serviceDown';
                    }, 3000);
                }
            });
            }
        return users.text;
    }

    $("#searchDeviceNameOutlookSearchFileGS").change(function () {
            console.log("inside change"+$('#searchDeviceNameOutlookSearchFileGS').val());
            var uuid = $('#searchDeviceNameOutlookSearchFileGS').val();
            $("#uuuOutlookSearchFileGS").val(uuid);

    });

$('.timePicker').timepicker({
        showMeridian: false,
    });    
    
$('.restoreDateOutlookSearchFileGS').datepicker({
        format: 'dd-M-yyyy',
        autoclose: true,
        todayHighlight: true,
        container:'.restoreBuckettOutlookSearchFileGS'
    }).attr('readonly', 'readonly');

$(".restoreDateOutlookSearchFileGS").datepicker().datepicker("setDate", new Date());

$("#switchDateOutlookSearchFileGS").click(function(){
    if ($(this).is(':checked')) {
        $('#restoreDateOutlookSearchFileGS').removeAttr('disabled');
        $('#restoreTimeOutlookSearchFileGS').removeAttr('disabled');        
    } else {
        $('#restoreDateOutlookSearchFileGS').attr('disabled', true); //disable input
        $('#restoreTimeOutlookSearchFileGS').attr('disabled', true);        
    }
});


$("#switchinplaceOutlookSearchFileGS").click(function(){
    if ($(this).is(':checked')) {
        $('#destinationPathOutlookSearchFileGS').val('');
        $('#destinationPathOutlookSearchFileGS').removeAttr('required', 'required');
        $('#destinationPathlabelOutlookSearchFileGS').removeClass('star');
        $('#destinationPathOutlookSearchFileGS').attr('disabled', true);
        $('#browseOutlookSearchFileGS').attr('disabled', true);
    } else {
        $('#destinationPathOutlookSearchFileGS').val('');
        $('#destinationPathOutlookSearchFileGS').removeAttr('disabled');
        $('#destinationPathlabelOutlookSearchFileGS').addClass('star');
        $('#destinationPathOutlookSearchFileGS').attr('required', 'required');
        $('#browseOutlookSearchFileGS').removeAttr('disabled');
    }
});
</script>
<div class="text-center">
    <a href="https://www.parablu.com" target="_blank" style="font-weight:600 !important;">© <?=COPYRIGHT_NAME?> <?=date('Y')?> </a>
    <br/><br/>
</div>
</body>
</html>

==> patch-2.5.5.0_3.zip: app/templates/default/footer.php <==
<!-- FOR EVERY PAGE THE BELOW CODE SHOULD BE ADDED -->
<?php use Helpers\Session;?>
<?php $session = new Session();?>
<script>
    NProgress.start();
    var interval = setInterval(function() { NProgress.inc(); }, 1000);
    //$(window).load(function () {
    $(window).on('load',function () {
        clearInterval(interval);
        NProgress.done();
    });
    //$(window).unload(function () {
    $(window).on('unload',function () {
        NProgress.start();
    });
    if($('.selectPicker')){
        $('.selectPicker').selectpicker();
    }
</script>
<script>
$('.my-dropdown').dropdown();
$('.my-dropdown').tooltip();
</script>
<?php if(ENABLE_IDEAL_TIMEOUT == true){?>
<script>
$(document).mousemove(function() {
ResetTimers();
});
// Logout the user.
function IdleTimeout() {
var env = $('.paracloudIP').html();
env = $('.protocol').html()+env+"/portal/logout";
var logoutUrl = env;
    window.location = logoutUrl;
}
    /*end*/
</script>
<?php } ?>

<script>         
    $('.searchUsernameOutlookSearchFileGS').select2({
        ajax: {
            url: "<?=DIR?>"+"user/searchUserWithDevice",
            dataType: 'json',
            delay: 250,
            data: function (params) {
                return {
                    q: params.term, // search term
                    page: params.page
                };
            },
            processResults: function (data, params) {
                params.page = params.page || 1;
                if(data.users.length > 0){
                    $('.assignSaveBtn').removeAttr('disabled');
                }
                return {
                    results: $.map(data.users, function (o) {
                        return { id: o.userName, text: o.userName, img: o.profilePic, devices: o.devices };
                    }),
                    pagination: {
                        more: (params.page * 30) < data.total_count
                    }
                };
            },
            cache: true
        },
        escapeMarkup: function (markup) { return markup; }, // let our custom formatter work
        minimumInputLength: 3,
        dropdownParent: $('.restoreBuckettOutlookSearchFileGS'),
        templateResult: selectTemplateResultOutlookSearchFileGS,
        templateSelection: selectTemplateSelectionOutlookSearchFileGS,
        placeholder: 'Select user'
    });

    function selectTemplateResultOutlookSearchFileGS(users){
        if(users.text != undefined){
            var template = "<div class='select2-result-repository clearfix'><div class='select2-result-repository__avatar'>";
            if(users.img){
                template += "<img style='-webkit-border-radius: 50px;-moz-border-radius: 50px;border-radius: 50px;' width='30px' height='30px' src='"+ users.img +"'> ";
            }
            template += users.text + "</div></div>";
            return template;
        }else{
            return "<div class='select2-user-result'>Fetching...</div>";
        }
    }

    function selectTemplateSelectionOutlookSearchFileGS(users){
            console.log("gggggggg : "+users.text);
            if(users.text != 'Select user'){
            $.ajax({
            url: "<?=DIR?>"+"getDeviceOutlook",
            data: {username: users.text, csrf_token: $('.csrf_token').html()},
            type: 'POST'
            }).done(function(data){
                console.log(data);
                var jData = JSON.parse(data);
                console.log("newone111 : "+jData.newone1);
                if (jData.newone1){
                var options = "";
                jData.newone1.forEach(function (device) {
                        options += '<option value="' + device.deviceUUID + '">' + device.deviceName + '</option>'
                });
                $('.searchDeviceNameOutlookSearchFileGS').html(options);
                /*xx start*/
                $("#uuuOutlookSearchFileGS").val(jData.newone1[0].deviceUUID);
                /*xx end*/
                    }else{
                    $('.searchDeviceNameOutlookSearchFileGS').html("<option value='all' selected>User has no devices configured</option>");
                    $('.searchDeviceNameOutlookSearchFileGS').attr("readonly", "readonly");
                    $("#uuuOutlookSearchFileGS").val('');
                }
            }).fail(function(data){
                if(data.status == 424){
                    setTimeout(function(){
                        window.location.href = $scope.BASE_FOLDER+'/sleep';
                    }, 3000);
                }else if(data.status == 503){
                    setTimeout(function(){
                        window.location.href = $scope.BASE_FOLDER+'/serviceDown';
                    }, 3000);
                }
            });
            }
        return users.text;
    }

    $("#searchDeviceNameOutlookSearchFileGS").change(function () {
            console.log("inside change"+$('#searchDeviceNameOutlookSearchFileGS').val());
            var uuid = $('#searchDeviceNameOutlookSearchFileGS').val();
            $("#uuuOutlookSearchFileGS").val(uuid);
    });

$('.timePicker').timepicker({
        showMeridian: false,
    });    
    
$('.restoreDateOutlookSearchFileGS').datepicker({
        format: 'dd-M-yyyy',
        autoclose: true,
        todayHighlight: true,
        container:'.restoreBuckettOutlookSearchFileGS'
    }).attr('readonly', 'readonly');

$(".restoreDateOutlookSearchFileGS").datepicker().datepicker("setDate", new Date());

$("#switchDateOutlookSearchFileGS").click(function(){
    if ($(this).is(':checked')) {
        $('#restoreDateOutlookSearchFileGS').removeAttr('disabled');
        $('#restoreTimeOutlookSearchFileGS').removeAttr('disabled');        
    } else {
        $('#restoreDateOutlookSearchFileGS').attr('disabled', true); //disable input
        $('#restoreTimeOutlookSearchFileGS').attr('disabled', true);        
    }
});

$("#switchinplaceOutlookSearchFileGS").click(function(){
    if ($(this).is(':checked')) {
        $('#destinationPathOutlookSearchFileGS').val('');
        $('#destinationPathOutlookSearchFileGS').removeAttr('required', 'required');
        $('#destinationPathlabelOutlookSearchFileGS').removeClass('star');
        $('#destinationPathOutlookSearchFileGS').attr('disabled', true);
        $('#browseOutlookSearchFileGS').attr('disabled', true);
    } else {
        $('#destinationPathOutlookSearchFileGS').val('');
        $('#destinationPathOutlookSearchFileGS').removeAttr('disabled');
        $('#destinationPathlabelOutlookSearchFileGS').addClass('star');
        $('#destinationPathOutlookSearchFileGS').attr('required', 'required');
        $('#browseOutlookSearchFileGS').removeAttr('disabled');
    }
});
    
    $('.searchUsernameAd').select2({
	    ajax: {
            url: "<?=DIR?>"+"user/searchUserWithDeviceForRestore",
            dataType: 'json',
            delay: 250,
            data: function (params) {
                return {
                    q: params.term, // search term
                    page: params.page
                };
            },
            processResults: function (data, params) {
                params.page = params.page || 1;
                if(data.users.length > 0){
                    $('.assignSaveBtn').removeAttr('disabled');
                }
                return {
                    results: $.map(data.users, function (o) {
                        return { id: o.userName, text: o.userName, img: o.profilePic, devices: o.devices };
                    }),
                    pagination: {
                        more: (params.page * 30) < data.total_count
                    }
                };
            },
            cache: true
        },
        escapeMarkup: function (markup) { return markup; }, // let our custom formatter work
        minimumInputLength: 3,
        templateResult: selectTemplateResult11,
        templateSelection: selectTemplateSelection11,
        placeholder: 'Select user'
    });

    function selectTemplateResult11(users){
        if(users.text != undefined){
            var template = "<div class='select2-result-repository clearfix'><div class='select2-result-repository__avatar'>";
            if(users.img){
                template += "<img style='-webkit-border-radius: 50px;-moz-border-radius: 50px;border-radius: 50px;' width='30px' height='30px' src='"+ users.img +"'> ";
            }
            template += users.text + "</div></div>";
            return template;
        }else{
            return "<div class='select2-user-result'>Fetching...</div>";
        }
    }

    function selectTemplateSelection11(users){
	    var productType = $('#searchProductAd').val();
            var url;
            if(productType == 'backup'){
                url = "<?=DIR?>"+"getDeviceEndPoint";
            }else if(productType == 'oneDrive'){
                url = "<?=DIR?>"+"getDeviceOnedrive";
            }else if(productType == 'mail'){
                url = "<?=DIR?>"+"getDeviceOutlook";
            }
	    $.ajax({
            url: url,
            data: {username: users.text, csrf_token: $('.csrf_token').html()},
            type: 'POST'
        }).done(function(data){
            console.log(data);
            var jData = JSON.parse(data);
	    if(jData.newone1){
            <?php if($session->get('admin') == '1'){?>	    
                    if (jData.newone1.length > 0){
            <?php } else { ?>
                    if (jData.newone1.length > 0){
            <?php } ?>
	        	var options = "";
                	jData.newone1.forEach(function (device) {
                    		options += '<option value="' + device.deviceName + '">' + device.deviceName + '</option>'
                	});
                	$('.searchDeviceNameAd').html(options);
	        }else{
	    	    	$('.searchDeviceNameAd').html("<option value='all' selected>User has no devices configured</option>");
                	$('.searchDeviceNameAd').attr("readonly", "readonly");
	        }
	    }else{
            	$('.searchDeviceNameAd').html("<option value='all' selected>User has no devices configured</option>");
                $('.searchDeviceNameAd').attr("readonly", "readonly");
            }
        }).fail(function(data){
            if(data.status == 424){
                setTimeout(function(){
                    window.location.href = $scope.BASE_FOLDER+'/sleep';
                }, 3000);
            }else if(data.status == 503){
                setTimeout(function(){
                    window.location.href = $scope.BASE_FOLDER+'/serviceDown';
                }, 3000);
            }
        });
        return users.text;
    }

    /* for full start*/
    $('.searchUsernameFull').select2({
        ajax: {
	     url: "<?=DIR?>"+"user/searchUserWithDeviceForRestore",
            dataType: 'json',
            delay: 250,
            data: function (params) {
                return {
                    q: params.term, // search term
                    page: params.page
                };
            },
            processResults: function (data, params) {
                params.page = params.page || 1;
                if(data.users.length > 0){
                    $('.assignSaveBtn').removeAttr('disabled');
                }
                return {
                    results: $.map(data.users, function (o) {
                        return { id: o.userName, text: o.userName, img: o.profilePic, devices: o.devices };
                    }),
                    pagination: {
                        more: (params.page * 30) < data.total_count
                    }
                };
            },
            cache: true
        },
        escapeMarkup: function (markup) { return markup; }, // let our custom formatter work
        minimumInputLength: 3,
        templateResult: selectTemplateResultFull,
        templateSelection: selectTemplateSelectionFull,
        placeholder: 'Select user'
    });

    function selectTemplateResultFull(users){
        if(users.text != undefined){
            var template = "<div class='select2-result-repository clearfix'><div class='select2-result-repository__avatar'>";
            if(users.img){
                template += "<img style='-webkit-border-radius: 50px;-moz-border-radius: 50px;border-radius: 50px;' width='30px' height='30px' src='"+ users.img +"'> ";
            }
            template += users.text + "</div></div>";
            return template;
        }else{
            return "<div class='select2-user-result'>Fetching...</div>";
        }
    }

    function selectTemplateSelectionFull(users){
            var productType = $('#searchProductFull').val();
            var url;
            if(productType == 'backup' || productType == 'sync'){
                url = "<?=DIR?>"+"getDeviceEndPoint";
            }else if(productType == 'oneDrive'){
                url = "<?=DIR?>"+"getDeviceOnedrive";
            }else if(productType == 'mail'){
                url = "<?=DIR?>"+"getDeviceOutlook";
            }
            $.ajax({
            url: url,
            data: {username: users.text, csrf_token: $('.csrf_token').html()},
            type: 'POST'
        }).done(function(data){
            console.log(data);
            var jData = JSON.parse(data);
	    console.log("newone111 : "+jData.newone1);
	    if(jData.newone1){
	    	<?php if($session->get('admin') == '1'){?>
	    		if (jData.newone1.length > 0){
        	<?php } else { ?>
            		if (jData.newone1){
        	<?php } ?>
            			var options = "";
	    			jData.newone1.forEach(function (device) {
                    			options += '<option value="' + device.deviceId + '">' + device.deviceName + '</option>'
	    			});
	    			$('.searchDeviceNameFull').html(options);
            		}else{
				$('.searchDeviceNameFull').html("<option value='all' selected>User has no devices configured</option>");
				$('.searchDeviceNameFull').attr("readonly", "readonly");
            		}
	    }else{
		$('.searchDeviceNameFull').html("<option value='all' selected>User has no devices configured</option>");
                $('.searchDeviceNameFull').attr("readonly", "readonly");
	    }
	}).fail(function(data){
            if(data.status == 424){
                setTimeout(function(){
                    window.location.href = $scope.BASE_FOLDER+'/sleep';
                }, 3000);
            }else if(data.status == 503){
                setTimeout(function(){
                    window.location.href = $scope.BASE_FOLDER+'/serviceDown';
                }, 3000);
            }
	});
        return users.text;
    }
	    /*for full end*/

    $("[data-toggle=tooltip]").tooltip({
        placement: $(this).data("placement") || 'right'
    });    
</script>
<div class="text-center">
    <a href="https://www.parablu.com" target="_blank" style="font-weight:600 !important;">© <?=COPYRIGHT_NAME?> <?=date('Y')?> </a>
    <br/><br/>
</div>
</body>
</html>
